<?xml version="1.0"  encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects. 
======================================================================= -->
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xalan="http://xml.apache.org/xalan">



<xsl:template name="standard-analysis-classes">
    <xsl:param name="reports-element"/>
	<xsl:param name="packages-element"/>
	<xsl:param name="subsystem-name"/>
	<xsl:param name="single-package"/>
	<xsl:param name="package-element"/>

    <html>
	<head>
         <link rel="stylesheet" type="text/css" href="../stylesheet.css"/>
	</head>
    <body>

    <xsl:call-template name="page-header">
       <xsl:with-param name="page-name">
        <xsl:choose>
            <xsl:when test="$single-package='true'"><xsl:value-of select="concat('Class Analysis - ',' ',/radar-report/@system,' - ', $package-element/@name)"/></xsl:when>
            <xsl:when test="not($subsystem-name)"><xsl:value-of select="concat('Class Analysis - ',/radar-report/@system)"/></xsl:when>
            <xsl:otherwise><xsl:value-of select="concat('Class Analysis - ',' ',/radar-report/@system,' ',$subsystem-name)"/></xsl:otherwise>
         </xsl:choose>
       </xsl:with-param>
       <xsl:with-param name="main-menu-page-name" select="'analysis'"/> 
       <xsl:with-param name="page-type"  select="'class analysis'"/>
        <xsl:with-param name="subsystem-name" select="$subsystem-name"/>
        <xsl:with-param name="single-package" select="$single-package"/>
        <xsl:with-param name="package-name">
            <xsl:choose>
                <xsl:when test="$single-package='true'"><xsl:value-of select="$package-element/@name"/></xsl:when>
                <xsl:otherwise></xsl:otherwise>
            </xsl:choose>
        </xsl:with-param>
    </xsl:call-template>

    <hr size="1"/>
    <p>
        The classes are sorted by the total number of method changes 
        multiplied by the mean cyclomatic complexity on the class. 
    </p>

    <table class="details">
        <tr>
            <th>Rank</th><th>Methods</th><th>Method Changes</th><th>Source Statements</th><th>Cyclomatic Complexity per Method</th>
            <xsl:if test="((not($single-package = 'true')) and ($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/test-metrics)) or
							(($single-package = 'true') and ($package-element/statistics/test-metrics))">
                <th>Test Coverage</th>
            </xsl:if>
            <th>Package</th><th>Class</th>
        </tr>

        <xsl:choose>
        <xsl:when test="$single-package='true'">
            <xsl:for-each select="$package-element/classes/class">
                <xsl:sort select="count(methods/method/statistics/ncss/value[@changed-since-last='true'])
                                	* (sum(methods/method/statistics/ccn/value[(position()=last()) and (@value != '')]/@value) div count(methods/method))"
                                	order="descending" 
                          			data-type="number"/> 
                                	
                <xsl:if test="position() &lt;= 100">
					<xsl:apply-templates select="current()">
						<xsl:with-param name="position" select="position()" />
						<xsl:with-param name="packages-element" select="$packages-element" />
						<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
						<xsl:with-param name="single-package" select="$single-package"/>
						<xsl:with-param name="package-element" select="$package-element"/>				
					</xsl:apply-templates>   
                </xsl:if>
            </xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
            <xsl:for-each select="$packages-element/package[starts-with(@subsystem,$subsystem-name)]/classes/class">
                <xsl:sort select="count(methods/method/statistics/ncss/value[@changed-since-last='true'])
                                	* (sum(methods/method/statistics/ccn/value[(position()=last()) and (@value != '')]/@value) div count(methods/method))"
                                	order="descending" 
                          			data-type="number"/>
                <xsl:if test="position() &lt;= 100">
                	<xsl:apply-templates select="current()">
						<xsl:with-param name="position" select="position()" />
						<xsl:with-param name="packages-element" select="$packages-element" />
						<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
						<xsl:with-param name="single-package" select="$single-package"/>
						<xsl:with-param name="package-element" select="$package-element"/>				
					</xsl:apply-templates>                		    	
                </xsl:if>
            </xsl:for-each>
        </xsl:otherwise>
        </xsl:choose>
    </table>

    </body>
    </html>
</xsl:template>

<xsl:template match="class">
	<xsl:param name="position"/>
	<xsl:param name="packages-element"/>
	<xsl:param name="subsystem-name"/>
	<xsl:param name="single-package"/>
	<xsl:param name="package-element"/>
	<tr>
        <td><xsl:value-of select="$position"/></td>
        <td><xsl:value-of select="count(methods/method)"/></td>
        <td><xsl:value-of select="count(methods/method/statistics/ncss/value[@changed-since-last='true'])"/></td>
        <td><xsl:value-of select="sum(methods/method/statistics/ncss/value[(position()=last()) and (@value != '')]/@value)"/></td>
        <td><xsl:value-of select="format-number(sum(methods/method/statistics/ccn/value[(position() = last()) and (@value != '')]/@value) div count(methods/method),'#.#')"/></td>
        <xsl:if test="((not($single-package = 'true')) and ($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/test-metrics)) or
							(($single-package = 'true') and ($package-element/statistics/test-metrics))">
        	<xsl:variable name="source-statements-covered" 
					select="sum(descendant::source-statements-covered/value
								[	
									((position() = last()) and not(@value='NaN') and not(@value=''))
									
								]/@value)"/>
			<xsl:variable 	name="source-statements" 
				  	select="sum(descendant::ncss/value
								[	
									((position() = last()) and not(@value='NaN') and not(@value=''))												
								]/@value)"/>
            <td><xsl:value-of select="format-number($source-statements-covered div $source-statements,'#.##')"/></td>
        </xsl:if>                        
        <td><xsl:value-of select="../../@name"/></td>
        <td><xsl:value-of select="@name"/></td>
    </tr>
	
</xsl:template>

</xsl:stylesheet>

