<?xml version="1.0"  encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:redirect="http://xml.apache.org/xalan/redirect"
  	extension-element-prefixes="redirect">


<xsl:template name="standard-analysis-code-quality">
	<xsl:param name="reports-element"/>
	<xsl:param name="packages-element"/>
	<xsl:param name="subsystem-name"/>
	<xsl:param name="single-package"/>
	<xsl:param name="package-element"/>

    <xsl:variable name="mean-ccn-per-method"
    	select="sum($packages-element/package/statistics/source-metrics/ccn/value[@seq-id='1']/@value)
			div sum($packages-element/package/statistics/source-metrics/functions/value[@seq-id='1']/@value)"/>
	<xsl:variable name="mean-violations-per-ncss"
		select="sum($packages-element/package/statistics/source-metrics/code-violations/value[@seq-id='1']/@value)
			div sum($packages-element/package/statistics/source-metrics/ncss/value[@seq-id='1']/@value)"/>
	<xsl:variable name="mean-style-errors-per-ncss"
	    select="sum($packages-element/package/statistics/source-metrics/style-errors/value[@seq-id='1']/@value)
			div sum($packages-element/package/statistics/source-metrics/ncss/value[@seq-id='1']/@value)"/>

	<xsl:variable name="file-identifier">
   		<xsl:choose>
 			<xsl:when test="$single-package='true'">
		 		<xsl:value-of select="$package-element/@name"/>
			</xsl:when>
	        <xsl:otherwise>
	            <xsl:value-of select="$subsystem-name"/>
	        </xsl:otherwise>
        </xsl:choose>
   </xsl:variable>

   <xsl:variable name="catalog-identifier">
   		<xsl:choose>
 			<xsl:when test="$single-package='true'">
		 		<xsl:value-of select="'packages'"/>
			</xsl:when>
	        <xsl:otherwise>
	            <xsl:value-of select="'subsystems'"/>
	        </xsl:otherwise>
        </xsl:choose>
   </xsl:variable>



	<h3>Code Quality Metrics :</h3>
	<table class="details">
		<tr><td style="background-color: white;">
	            <div align="center">
	              <embed width="460" height="275" src="../img/code-violations-per-ncss-image-{$file-identifier}.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
	            </div>
            </td>
            <td style="background-color: white;">
	            <div align="center">
	              <embed width="460" height="275" src="../img/style-errors-per-ncss-image-{$file-identifier}.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
	            </div>
            </td>
	 	</tr>
        <tr><td style="background-color: white;">
	            <div align="center">
	              <embed width="460" height="275" src="../img/code-duplications-image-{$file-identifier}.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
	            </div>
            </td>
            <td style="background-color: white;">
	            <div align="center">
	              <embed width="460" height="275" src="../img/code-duplicated-tokens-per-ncss-image-{$file-identifier}.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
	            </div>
            </td>
	 	</tr>

	</table>

	<a href="javascript:winpopanalysisdetails('code-quality-details-popup-{$file-identifier}.html')">[Code Quality Details]</a><br/>

	<redirect:write file="{$docs-home}/{$catalog-identifier}/code-quality-details-popup-{$file-identifier}.html">
		 <xsl:call-template name="standard-analysis-code-quality-details">
			<xsl:with-param name="reports-element" select="$reports-element"/>
			<xsl:with-param name="packages-element" select="$packages-element"/>
			<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
			<xsl:with-param name="single-package" select="$single-package"/>
			<xsl:with-param name="package-element" select="$package-element"/>
		    <xsl:with-param name="mean-ccn-per-method" select="$mean-ccn-per-method"/>
			<xsl:with-param name="mean-violations-per-ncss" select="$mean-violations-per-ncss"/>
			<xsl:with-param name="mean-style-errors-per-ncss" select="$mean-style-errors-per-ncss"/>
		 </xsl:call-template>
   	 </redirect:write>

    <redirect:write file="{$docs-home}/img/code-violations-per-ncss-image-{$file-identifier}.svg">
        <xsl:call-template name="standard-dynamics-line-graph">
            <xsl:with-param name="text-y-axis" select="'Code Violations per Source Statements'"/>
            <xsl:with-param name="primary-metric-group" select="'source-metrics'"/>
            <xsl:with-param name="primary-metric" select="'code-violations'"/>
            <xsl:with-param name="divisor-metric-group" select="'source-metrics'"/>
            <xsl:with-param name="divisor-metric" select="'ncss'"/>

			<xsl:with-param name="reports-element" select="$reports-element"/>
			<xsl:with-param name="packages-element" select="$packages-element"/>
			<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
			<xsl:with-param name="single-package" select="$single-package"/>
			<xsl:with-param name="package-element" select="$package-element"/>
		 </xsl:call-template>
	</redirect:write>

    <redirect:write file="{$docs-home}/img/style-errors-per-ncss-image-{$file-identifier}.svg">
        <xsl:call-template name="standard-dynamics-line-graph">
            <xsl:with-param name="text-y-axis" select="'Style Errors per Source Statements'"/>
            <xsl:with-param name="primary-metric-group" select="'source-metrics'"/>
            <xsl:with-param name="primary-metric" select="'style-errors'"/>
            <xsl:with-param name="divisor-metric-group" select="'source-metrics'"/>
            <xsl:with-param name="divisor-metric" select="'ncss'"/>

			<xsl:with-param name="reports-element" select="$reports-element"/>
			<xsl:with-param name="packages-element" select="$packages-element"/>
			<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
			<xsl:with-param name="single-package" select="$single-package"/>
			<xsl:with-param name="package-element" select="$package-element"/>
		 </xsl:call-template>
	</redirect:write>

    <redirect:write file="{$docs-home}/img/code-duplications-image-{$file-identifier}.svg">
        <xsl:call-template name="standard-dynamics-line-graph">
            <xsl:with-param name="text-y-axis" select="'Code Duplications'"/>
            <xsl:with-param name="primary-metric-group" select="'duplication-metrics'"/>
            <xsl:with-param name="primary-metric" select="'duplications'"/>

			<xsl:with-param name="reports-element" select="$reports-element"/>
			<xsl:with-param name="packages-element" select="$packages-element"/>
			<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
			<xsl:with-param name="single-package" select="$single-package"/>
			<xsl:with-param name="package-element" select="$package-element"/>
		 </xsl:call-template>
	</redirect:write>

    <redirect:write file="{$docs-home}/img/code-duplicated-tokens-per-ncss-image-{$file-identifier}.svg">
        <xsl:call-template name="standard-dynamics-line-graph">
            <xsl:with-param name="text-y-axis" select="'Duplicated Tokens per Source Statements'"/>
            <xsl:with-param name="primary-metric-group" select="'duplication-metrics'"/>
            <xsl:with-param name="primary-metric" select="'tokens'"/>
            <xsl:with-param name="divisor-metric-group" select="'source-metrics'"/>
            <xsl:with-param name="divisor-metric" select="'ncss'"/>

			<xsl:with-param name="reports-element" select="$reports-element"/>
			<xsl:with-param name="packages-element" select="$packages-element"/>
			<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
			<xsl:with-param name="single-package" select="$single-package"/>
			<xsl:with-param name="package-element" select="$package-element"/>
		 </xsl:call-template>
	</redirect:write>

</xsl:template>

<xsl:template name="standard-analysis-code-quality-details">
	<xsl:param name="reports-element"/>
	<xsl:param name="packages-element"/>
	<xsl:param name="subsystem-name"/>
	<xsl:param name="single-package"/>
	<xsl:param name="package-element"/>
    <xsl:param name="mean-ccn-per-method"/>
	<xsl:param name="mean-violations-per-ncss"/>
	<xsl:param name="mean-style-errors-per-ncss"/>
	<html>
	<head>
         <link rel="stylesheet" type="text/css" href="../stylesheet.css"/>
	</head>
    <body>

	<table class="details">
		<tr><th>Version</th><th>Date</th><th>Cycl. Cmplx. [CC]</th><th>[CC]/[SS]</th><th>[CC]/Methods</th><th>Violations</th><th>[Violations]/[SS]</th><th>Style Errors</th><th>Style Er./[SS]</th><th>Code Duplications</th><th>Duplicated Tokens [DK]</th><th> [DK] / [SS]</th></tr>
		<xsl:for-each select="$reports-element/report">
			<xsl:sort select="@seq-id"/>

			<xsl:variable name="current-seq-id" select="@seq-id"/>

				<xsl:choose>
				<xsl:when test="$single-package='true'">
			 		<xsl:if test="$package-element/statistics/source-metrics/ncss/value[@seq-id=$current-seq-id]">
				 		<xsl:variable name="ncss" select="$package-element/statistics/source-metrics/ncss/value[@seq-id=$current-seq-id]/@value"/>
		  				<xsl:variable name="ccn" select="$package-element/statistics/source-metrics/ccn/value[@seq-id=$current-seq-id]/@value"/>
						<xsl:variable name="ccn-per-ncss" select="$ccn div $ncss"/>

						<xsl:variable name="methods" select="$package-element/statistics/source-metrics/functions/value[@seq-id=$current-seq-id]/@value"/>
						<xsl:variable name="ccn-per-method" select="$ccn div $methods"/>
						<xsl:variable name="violations" select="$package-element/statistics/source-metrics/code-violations/value[@seq-id=$current-seq-id]/@value"/>
						<xsl:variable name="violations-per-ncss" select="$violations div $ncss"/>
						<xsl:variable name="style-errors" select="$package-element/statistics/source-metrics/style-errors/value[@seq-id=$current-seq-id]/@value"/>
						<xsl:variable name="style-errors-per-ncss" select="$style-errors div $ncss"/>
						<xsl:variable name="duplications" select="sum($package-element/statistics/duplication-metrics/duplications/value[@seq-id=$current-seq-id]/@value)"/>
						<xsl:variable name="duplicated-tokens" select="sum($package-element/statistics/duplication-metrics/tokens/value[@seq-id=$current-seq-id]/@value)"/>
						<xsl:variable name="duplicated-tokens-per-ncss" select="$duplicated-tokens div $ncss"/>
                         <tr>
							<td><xsl:value-of select="version"/></td>
							<td><xsl:value-of select="date"/></td>
							<td><xsl:value-of select="$ccn"/></td>
							<td><xsl:value-of select="format-number($ccn-per-ncss, '#.##')"/></td>
							<td><xsl:value-of select="format-number($ccn div $methods, '#.##')"/></td>
							<td><xsl:value-of select="$violations"/></td>
							<td><xsl:value-of select="format-number($violations div $ncss, '#.##')"/></td>
							<td><xsl:value-of select="$style-errors"/></td>
							<td><xsl:value-of select="format-number($style-errors div $ncss, '#.##')"/></td>
                            <td><xsl:value-of select="$duplications"/></td>
                            <td><xsl:value-of select="$duplicated-tokens"/></td>
                            <td><xsl:value-of select="$duplicated-tokens-per-ncss"/></td>
						</tr>
					</xsl:if>
				</xsl:when>

		        <xsl:otherwise>
		            <xsl:if test="$packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/source-metrics/ncss/value[@seq-id=$current-seq-id]">
			            <xsl:variable name="ncss" select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/source-metrics/ncss/value[@seq-id=$current-seq-id]/@value)"/>
						<xsl:variable name="ccn" select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/source-metrics/ccn/value[@seq-id=$current-seq-id]/@value)"/>
						<xsl:variable name="ccn-per-ncss" select="$ccn div $ncss"/>

						<xsl:variable name="methods" select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/source-metrics/functions/value[@seq-id=$current-seq-id]/@value)"/>
						<xsl:variable name="ccn-per-method" select="$ccn div $methods"/>
						<xsl:variable name="violations" select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/source-metrics/code-violations/value[@seq-id=$current-seq-id]/@value)"/>
						<xsl:variable name="violations-per-ncss" select="$violations div $ncss"/>
						<xsl:variable name="style-errors" select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/source-metrics/style-errors/value[@seq-id=$current-seq-id]/@value)"/>
						<xsl:variable name="style-errors-per-ncss" select="$style-errors div $ncss"/>
						<xsl:variable name="duplications" select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/duplication-metrics/duplications/value[@seq-id=$current-seq-id]/@value)"/>
						<xsl:variable name="duplicated-tokens" select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/duplication-metrics/tokens/value[@seq-id=$current-seq-id]/@value)"/>
						<xsl:variable name="duplicated-tokens-per-ncss" select="$duplicated-tokens div $ncss"/>

						<tr>
							<td><xsl:value-of select="version"/></td>
							<td><xsl:value-of select="date"/></td>
							<td><xsl:value-of select="$ccn"/></td>
							<td><xsl:value-of select="format-number($ccn-per-ncss, '#.##')"/></td>
							<td><xsl:value-of select="format-number($ccn div $methods, '#.##')"/></td>
							<td><xsl:value-of select="$violations"/></td>
							<td><xsl:value-of select="format-number($violations div $ncss, '#.##')"/></td>
							<td><xsl:value-of select="$style-errors"/></td>
							<td><xsl:value-of select="format-number($style-errors div $ncss, '#.##')"/></td>
                            <td><xsl:value-of select="$duplications"/></td>
                            <td><xsl:value-of select="$duplicated-tokens"/></td>
                            <td><xsl:value-of select="format-number($duplicated-tokens-per-ncss, '#.##')"/></td>
						</tr>
					</xsl:if>
		        </xsl:otherwise>
		    </xsl:choose>

		</xsl:for-each>
	</table>

	</body>
	</html>

</xsl:template>




</xsl:stylesheet>
