<?xml version="1.0" encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

  <xsl:output method="html" encoding="UTF-8"/>


  <!-- this is the stylesheet css to use for nearly everything -->
  <xsl:template name="stylesheet.css">
  <xsl:param name="radar-config"/>
  <xsl:param name="log"/>
  <xsl:if test="$log = 'true'">
    <xsl:message>
Styles called with 
- 'radar-config':<xsl:value-of select="$radar-config/radar-config/@name"/>
- log : <xsl:value-of select="$log"/>
    </xsl:message>
  </xsl:if>
     
  <xsl:variable   name="color-ok">
    <xsl:call-template name="define-color">
       <xsl:with-param name="target" select="'3'"/>
       <xsl:with-param name="color" select="$radar-config/radar-config/defined-metrics/thresholds/threshold[@level = '3']/@color"/>
    </xsl:call-template>
  </xsl:variable>
  <xsl:variable   name="color-warn">
    <xsl:call-template name="define-color">
       <xsl:with-param name="target" select="'2'"/>
       <xsl:with-param name="color" select="$radar-config/radar-config/defined-metrics/thresholds/threshold[@level = '2']/@color"/>
    </xsl:call-template>
  </xsl:variable>
  <xsl:variable   name="color-ko">
    <xsl:call-template name="define-color">
       <xsl:with-param name="target" select="'1'"/>
       <xsl:with-param name="color" select="$radar-config/radar-config/defined-metrics/thresholds/threshold[@level = '1']/@color"/>
    </xsl:call-template>
  </xsl:variable>
  <xsl:variable name="link-color">
    <xsl:call-template name="define-color">
       <xsl:with-param name="target" select="'link-color'"/>
       <xsl:with-param name="color" select="$radar-config/radar-config/website/links/@color"/>
    </xsl:call-template>
  </xsl:variable>

  <xsl:if test="$log = 'true' ">
    <xsl:message>
Website colors are:
Level 1 : <xsl:value-of select="$color-ko"/>
Level 2 : <xsl:value-of select="$color-warn"/>
Level 3 : <xsl:value-of select="$color-ok"/>

Link color : <xsl:value-of select="$link-color"/>

    </xsl:message>
  </xsl:if>

   <style type="text/css">

    ko {
        color : <xsl:value-of select="$color-ko"/>;
    }

    warn {
        color : <xsl:value-of select="$color-warn"/>;
    }

    ok {
        color : <xsl:value-of select="$color-ok"/>;
    }


    body {
    font:normal 68% verdana,arial,helvetica;
    color:#000000;
    }
    table tr td, tr th {
      font-size: 68%;
    }
    table.details tr th{
    font-weight: bold;
    text-align:left;
    /* FIXME: table header coloring */
    background: #BFDE1D;
    }
    table.details tr td{
    /* FIXME: table row coloring */
    background:#eeeee0;
    }

    table.scorecard table{
    border: 2px solid #C0C0C0;
	align: top;
    }
    table.scorecard tr th{
    font-weight: bold;
    text-align:left;
/* FIXME: table row coloring */
    background:#C0C0C0;
    }
    table.scorecard tr td{
		background:white;
    }

    a:link {color: <xsl:value-of select="$link-color"/>; text-decoration: none; }
    a:active {color: <xsl:value-of select="$link-color"/>; text-decoration: none; }
    a:visited {color: <xsl:value-of select="$link-color"/>; text-decoration: none; }
    a:hover {color: #FE9F34; text-decoration: none; }


    p {
    line-height:1.5em;
    margin-top:0.5em; margin-bottom:1.0em;
    margin-left:2em;
    margin-right:2em;
    }
    h1 {
    margin: 0px 0px 5px; font: 165% verdana,arial,helvetica
    }
    h2 {
    margin-top: 1em; margin-bottom: 0.5em; font: bold 125% verdana,arial,helvetica
    }
    h3 {
    margin-bottom: 0.5em; font: bold 115% verdana,arial,helvetica
    }
    h4 {
    margin-bottom: 0.5em; font: bold 100% verdana,arial,helvetica
    }
    h5 {
    margin-bottom: 0.5em; font: bold 100% verdana,arial,helvetica
    }
    h6 {
    margin-bottom: 0.5em; font: bold 100% verdana,arial,helvetica
    }
    .Error {
    font-weight:bold; color:red;
    }
    .Failure {
    font-weight:bold; color:purple;
    }
    .Properties {
    text-align:right;
    }
  </style>
</xsl:template>

  <xsl:template name="define-color">
     <xsl:param name="target"/>
     <xsl:param name="color"/>
     <xsl:param name="log"/>

     <xsl:if test="$log != ''">
       <xsl:message>
         color: <xsl:value-of select="$color"/> for target: <xsl:value-of select="$target"/>
       </xsl:message>
     </xsl:if>
     
     <xsl:variable name="defined-color">
       <xsl:choose>
          <xsl:when test="$color = '' and $target = '1'">
            <xsl:value-of select="'#BFDE1D'"/>
          </xsl:when>
          <xsl:when test="$color = '' and $target = '2'">
            <xsl:value-of select="'#FE9F34'"/>
          </xsl:when>
          <xsl:when test="$color = '' and $target = '3'">
           <xsl:value-of select="'#FFFF00'"/>
          </xsl:when>
          <xsl:when test="$color = '' and $target = 'link-color'">
            <xsl:value-of select="'#FE9F34'"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$color"/>
          </xsl:otherwise>
       </xsl:choose>      
     </xsl:variable>
     <xsl:if test="$log">
       <xsl:message>
         defined color : <xsl:value-of select="$defined-color"/>
       </xsl:message>
     </xsl:if>

     <xsl:value-of select="$defined-color"/>

  </xsl:template>
</xsl:stylesheet>
